==> libjo_01_25.tar.gz: smarty_dir/templates_c/%%89^897^897F4CEF%%entry_confirm.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-25 20:03:09
         compiled from entry_confirm.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<body>
<!--全体-->
<div id="wrapper">
	<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div id="content">
	<div id="pan">

	</div> 
	<div id="center_main">
	<div id="entry_confirm">
	
	<h2> ユーザ登録の確認 </h2>

	<p> 学籍番号とパスワードは正しいですか? </p>
	
	<div id="info">

	<ul>
	<li> <span>学籍番号</span>:</li>
	<li> <?php echo $_POST['id']; ?>
 </li>
	</ul>
	<br />

	<ul>
	<li> <span>お名前</span>:</li>
	<li> <?php echo $_POST['name']; ?>
 </li>
	</ul>
	<br />
	
	<ul>
	<li> <span>パスワード</span>:</li>
	<li> <?php echo $_POST['pass1']; ?>
 </li>
	</ul>
	</div>	
	<br />
	
	<div id="submit">
	<form action="entry.php" method="POST">
		
		
			
	    	<div class="submit_left"><input type="submit" class="submit" name="Submit" value="修正" /> </div>
		<input type="hidden" name="id" value="<?php echo $_POST['id']; ?>
" />
</form>
		
<form action="entryed.php" method="POST">		
		
		<div class="submit_right">
		<input type="submit" class="submit" value="OK" /> 
		<input type="hidden" name="flag" value="true" />
		</div>
		</form> 	
	</div> 		
		
	</div> 	</div> 
</div> <?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

</body>
</html>

==> libjo_01_26.tar.gz: smarty_dir/templates_c/%%89^897^897F4CEF%%entry_confirm.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-26 17:13:44
         compiled from entry_confirm.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<body>
<!--全体-->
<div id="wrapper">
	<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div id="content">
	<div id="pan">

	</div> 
	<div id="center_main">
	<div id="entry_confirm">
	
	<h2> ユーザ登録の確認 </h2>

	<div id="info">
	<?php if ($this->_tpl_vars['err_flag'] == true): ?>
	<p> 学籍番号とパスワードはあっていますか? </p>
	<?php else: ?>

		<p>
		<?php if ($this->_tpl_vars['id_err'] == false): ?>
		学籍番号<?php echo $_POST['id']; ?>
は使われています。
		<br />
		<?php endif; ?>
		
		<?php if ($this->_tpl_vars['name_err'] == false): ?>
		名前<?php echo $_POST['name']; ?>
は使われています。
		<br />
		<?php endif; ?>
		
		<?php if ($this->_tpl_vars['pass_err'] == false): ?>
		違うパスワードを入力しています。
		<br />
		<?php endif; ?>
	<?php endif; ?>


	<ul>
	<li> <span>学籍番号</span>:</li>
	<li> <?php echo $_POST['id']; ?>
 </li>
	</ul>
	<br />

	<ul>
	<li> <span>お名前</span>:</li>
	<li> <?php echo $_POST['name']; ?>
 </li>
	</ul>
	<br />
	
	<ul>
	<li> <span>パスワード</span>:</li>
	<li> <?php echo $_POST['pass1']; ?>
 </li>
	</ul>

	</div>		<br />
	
	<div id="submit">
	<form action="entry.php" method="POST">
		
		
		<?php if ($this->_tpl_vars['err_flag'] == true): ?>	
	    	<div class="submit_left">
		<?php else: ?>
		<div class="submit_left" style="margin-left:30px;">
		<?php endif; ?>
		
		<input type="submit" class="submit" value="修正" /> </div>
		<input type="hidden" name="id" value="<?php echo $_POST['id']; ?>
" />
</form>



<?php if ($this->_tpl_vars['err_flag'] == true): ?>

<form action="entryed.php" method="POST">		
		
		<div class="submit_right">
		<input type="submit" class="submit" value="OK" /> 
		<input type="hidden" name="flag" value="true" />
		</div>
		</form> <?php endif; ?>	
	</div> 		
		
	</div> 	</div> 
</div> <?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

</body>
</html>
